@@ -8,6 +8,8 @@ to log messages including a simple console based print function if none is provi
 
 """
 
+from datetime import datetime
+
 class Base:
     def __init__(self, logger):
         #print ('core:logger is {}'.format(logger))
@@ -21,24 +23,31 @@ class Base:
 class SimpleLog:
     ' console based logging function that is used if no logging handler is passed'
     def __init__(self):
-        pass
+        self.dtformat = "%b %d %Y %H:%M:%S.%f"
 
     def Debug (self,level, message, caller=None):
-        print ('[DEBUG {}] {}'.format(level, message))
+        dt = datetime.now().strftime(self.dtformat)
+
+        print ('{} [DBG {}] {}'.format(dt, level, message))
 
     def Info (self,message, caller=None):
-        print ('[INFO] {}'.format( message))
+        dt = datetime.now().strftime(self.dtformat)
+        print ('{} [INF] {}'.format( dt, message))
 
     def Warning (self,message, caller=None):
-        print ('[WARNING] {}'.format( message))
+        dt = datetime.now().strftime(self.dtformat)
+        print ('{}  [WAR] {}'.format( dt, message))
 
     def Error (self,message, caller=None):
-        print ('[ERROR] {}'.format(message))
+        dt = datetime.now().strftime(self.dtformat)
+        print ('{} [ERR] {}'.format(dt, message))
 
     def Fatal (self,message, caller=None):
-        print ('[FATAL] {}'.format(message))
+        dt = datetime.now().strftime(self.dtformat)
+        print ('{} [FAT] {}'.format(dt, message))
         exit(-1)
 
     def Panic (self,message, caller=None):
-        print ('[PANIC] {}'.format(message))
+        dt = datetime.now().strftime(self.dtformat)
+        print ('{} [PNC] {}'.format(dt, message))
         exit(-2)
