@@ -43,7 +43,7 @@ class Yolo(Base):
         self.populate_class_labels()
 
        
-        self.lock_maximum=options.get(self.processor+'_max_processes' or 1)
+        self.lock_maximum=options.get(self.processor+'_max_processes') or 1
         self.lock_timeout = options.get(self.processor+'_max_lock_wait') or 120
         
         self.lock_name='pyzm_'+self.processor+'_lock'
